<template>
	<div class="app-container">
		<div class="search_form">
			<div>
				<span class="search_title">生产日期：</span>
				<el-date-picker v-model="searchForm.entryDate" value-format="YYYY-MM-DD" format="YYYY-MM-DD" type="daterange"
												placeholder="请选择" clearable @change="changeDaterange" />
				<span class="search_title ml10">生产人：</span>
				<el-input
					v-model="searchForm.customerName"
					style="width: 240px"
					placeholder="请输入"
					@change="handleQuery"
					clearable
					prefix-icon="Search"
				/>
				<el-button type="primary" @click="handleQuery" style="margin-left: 10px"
				>搜索</el-button
				>
			</div>
			<div>
				<el-button @click="handleOut">导出</el-button>
			</div>
		</div>
		<div class="table_list">
			<PIMTable
				rowKey="id"
				:column="tableColumn"
				:tableData="tableData"
				:page="page"
				:tableLoading="tableLoading"
				@pagination="pagination"
			></PIMTable>
		</div>
	</div>
</template>

<script setup>
import {onMounted, ref} from "vue";
import {
	listCustomer,
} from "@/api/basicData/customerFile.js";
import { ElMessageBox } from "element-plus";
import dayjs from "dayjs";
const { proxy } = getCurrentInstance();

const tableColumn = ref([
	{
		label: "生产日期",
		prop: "customerName",
		width: 120,
	},
	{
		label: "生产人",
		prop: "customerName",
		width: 120,
	},
	{
		label: "合同号",
		prop: "taxpayerIdentificationNumber",
		width: 220,
	},
	{
		label: "客户合同号",
		prop: "addressPhone",
		width: 250,
	},
	{
		label: "客户名称",
		prop: "contactPerson",
	},
	{
		label: "项目名称",
		prop: "contactPhone",
		width:150
	},
	{
		label: "产品大类",
		prop: "basicBankAccount",
		width: 220,
	},
	{
		label: "规格型号",
		prop: "bankAccount",
		width: 220,
	},
	{
		label: "单位",
		prop: "bankCode",
		width:220
	},
	{
		label: "工序",
		prop: "maintainer",
	},
	{
		label: "生产数量",
		prop: "maintenanceTime",
		width: 100,
	},
	{
		label: "工时定额",
		prop: "maintenanceTime",
		width: 100,
	},
	{
		label: "工资",
		prop: "maintenanceTime",
		width: 100,
	},
]);
const tableData = ref([]);
const tableLoading = ref(false);
const page = reactive({
	current: 1,
	size: 100,
	total: 0,
});

const data = reactive({
	searchForm: {
		customerName: "",
		entryDate: [
			dayjs().format("YYYY-MM-DD"),
			dayjs().add(1, "day").format("YYYY-MM-DD"),
		], // 录入日期
		entryDateStart: dayjs().format("YYYY-MM-DD"),
		entryDateEnd: dayjs().add(1, "day").format("YYYY-MM-DD"),
	},
});
const { searchForm } = toRefs(data);

// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
	page.current = 1;
	getList();
};
const pagination = (obj) => {
	page.current = obj.page;
	page.size = obj.limit;
	getList();
};
const changeDaterange = (value) => {
	if (value) {
		searchForm.entryDateStart = dayjs(value[0]).format("YYYY-MM-DD");
		searchForm.entryDateEnd = dayjs(value[1]).format("YYYY-MM-DD");
	} else {
		searchForm.entryDateStart = undefined;
		searchForm.entryDateEnd = undefined;
	}
	handleQuery();
};
const getList = () => {
	tableLoading.value = true;
	listCustomer({ ...searchForm.value, ...page }).then((res) => {
		tableLoading.value = false;
		tableData.value = res.records;
		page.total = res.total;
	});
};

// 导出
const handleOut = () => {
	ElMessageBox.confirm("选中的内容将被导出，是否确认导出？", "导出", {
		confirmButtonText: "确认",
		cancelButtonText: "取消",
		type: "warning",
	})
		.then(() => {
			proxy.download("/basic/customer/export", {}, "生产核算.xlsx");
		})
		.catch(() => {
			proxy.$modal.msg("已取消");
		});
};

onMounted(() => {
	getList();
});
</script>

<style scoped lang="scss"></style>
